Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Managed Streaming for Apache Kafka.

Actions, resources, and condition keys for Amazon Managed Streaming for Apache Kafka - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Managed Streaming for Apache Kafka

Amazon Managed Streaming for Apache Kafka (service prefix: `kafka` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

Topics

- Actions defined by Amazon Managed Streaming for Apache Kafka
- Resource types defined by Amazon Managed Streaming for Apache Kafka
- Condition keys for Amazon Managed Streaming for Apache Kafka

## Actions defined by Amazon Managed Streaming for Apache Kafka

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchAssociateScramSecret | Grants permission to associate one or more Scram Secrets with an Amazon MSK cluster. | Write |  |  | kms:CreateGrant kms:RetireGrant
BatchDisassociateScramSecret | Grants permission to disassociate one or more Scram Secrets from an Amazon MSK cluster. | Write |  |  | kms:RetireGrant
CreateCluster | Grants permission to create a cluster | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcs iam:AttachRolePolicy iam:CreateServiceLinkedRole iam:PutRolePolicy kms:CreateGrant kms:DescribeKey
CreateConfiguration | Grants permission to create a configuration. | Write |  |  |
DeleteCluster | Grants permission to delete a cluster. | Write |  |  |
DeleteConfiguration | Grants permission to delete the specified MSK configuration. | Write |  |  |
DescribeCluster | Grants permission to describe a cluster. | Read |  |  |
DescribeClusterOperation | Returns a description of the cluster operation specified by the ARN. | Read |  |  |
DescribeConfiguration | Grants permission to describe a configuration. | Read |  |  |
DescribeConfigurationRevision | Grants permission to describe a configuration revision. | Read |  |  |
GetBootstrapBrokers | Grants permission to get connection details for the broker nodes in a cluster. | Read |  |  |
GetCompatibleKafkaVersions | Returns a list of the Apache Kafka versions to which you can update this cluster. | List |  |  |
ListClusterOperations | Returns a list of all the operations that have been performed on the specified MSK cluster. | List |  |  |
ListClusters | Grants permission to return a list of all clusters in the current account. | List |  |  |
ListConfigurations | Grants permission to return a list of all configurations in the current account. | List |  |  |
ListNodes | Grants permission to return a list of nodes in a cluster. | List |  |  |
ListScramSecrets | Grants permission to return a list of the Scram Secrets associated with an Amazon MSK cluster. | List |  |  |
ListTagsForResource | Grants permission to list tags of a MSK resource. | List | cluster |  |
TagResource | Grants permission to tag a MSK resource. | Tagging | cluster |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove tags from a MSK resource. | Tagging | cluster |  |
| aws:TagKeys |
UpdateBrokerCount | Updates the number of broker nodes of the cluster. | Write |  |  |
UpdateBrokerStorage | Updates the storage size of the broker nodes of the cluster | Write |  |  |
UpdateClusterConfiguration | Update Kafka configuration running on a cluster. | Write |  |  |
UpdateClusterKafkaVersion | Updates the cluster to the specified Apache Kafka version. | Write |  |  |
UpdateConfiguration | Grants permission to create a new revision of the configuration. | Write |  |  |
UpdateMonitoring | Updates the monitoring settings for the cluster. | Write |  |  |

## Resource types defined by Amazon Managed Streaming for Apache Kafka

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
cluster | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:cluster/$ { ClusterName}/$ { UUID}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Managed Streaming for Apache Kafka

Amazon Managed Streaming for Apache Kafka defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access based on the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters access based on tag-value associated with a MSK resource | String
aws:TagKeys | Filters access based on the presence of mandatory tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.